Enum Request
#[non_exhaustive]pub enum Request {
SetMode {
mode: ZwlrOutputModeV1,
},
SetCustomMode {
width: i32,
height: i32,
refresh: i32,
},
SetPosition {
x: i32,
y: i32,
},
SetTransform {
transform: WEnum<Transform>,
},
SetScale {
scale: f64,
},
SetAdaptiveSync {
state: WEnum<AdaptiveSyncState>,
},
}Available on crate feature
wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SetMode
set the mode
This request sets the head’s mode.
Fields

mode: ZwlrOutputModeV1SetCustomMode
set a custom mode
This request assigns a custom mode to the head. The size is given in physical hardware units of the output device. If set to zero, the refresh rate is unspecified.
It is a protocol error to set both a mode and a custom mode.
Fields
SetPosition
set the position
This request sets the head’s position in the global compositor space.
Fields
SetTransform
set the transform
This request sets the head’s transform.
SetScale
set the scale
This request sets the head’s scale.
SetAdaptiveSync
enable/disable adaptive sync
This request enables/disables adaptive sync. Adaptive sync is also known as Variable Refresh Rate or VRR.
Only available since version 4 of the interface
Fields

state: WEnum<AdaptiveSyncState>Implementations